@@ -38,7 +38,7 @@ typedef struct type_wrap {
 	t_groups groups;
 } t_wrap;
 
-int cgi_pid;
+static int cgi_pid;
 
 void ALRM_handler() {
 	if (kill(cgi_pid, SIGTERM) != -1) {
