@@ -86,9 +86,14 @@ typedef struct {
 	bool config_check;
 } t_settings;
 
-volatile int received_signal = rs_NONE;
-bool must_quit = false;
-int open_connections = 0;
+static volatile int received_signal = rs_NONE;
+static bool must_quit = false;
+#ifdef ENABLE_MONITOR
+static int open_connections = 0;
+#endif
+#ifdef ENABLE_LOADCHECK
+static double current_server_load = 0;
+#endif
 
 char *hs_conlen      = "Content-Length: "; /* 16 */
 char *hs_forwarded   = "X-Forwarded-For:"; /* 16 */
@@ -97,6 +102,7 @@ char *fb_symlink     = "symlink not allowed";
 char *fb_accesslist  = "access denied via accesslist";
 char *fb_alterlist   = "access denied via alterlist";
 char *version_string = "Hiawatha v"VERSION
+
 #ifdef ENABLE_CACHE
 	", cache"
 #endif
@@ -1075,6 +1081,13 @@ void task_runner(t_config *config) {
 	t_ip_addr ip_addr;
 	int delay = 0;
 	time_t now;
+#ifdef ENABLE_LOADCHECK
+	FILE *load_fp = NULL;
+	char load_str[50], *c;
+#ifdef ENABLE_MONITOR
+	int  load_monitor_timer = 0;
+#endif
+#endif
 
 	do {
 		sleep(1);
@@ -1121,6 +1134,42 @@ void task_runner(t_config *config) {
 		check_admin_list();
 #endif
 
+#ifdef ENABLE_LOADCHECK
+		if (config->max_server_load > 0) {
+			if ((load_fp = fopen("/proc/loadavg", "r")) != NULL) {
+				if (fgets(load_str, 49, load_fp) != NULL) {
+					load_str[49] = '\0';
+					if ((c = strchr(load_str, ' ')) != NULL) {
+						*c = '\0';
+						current_server_load = atof(load_str);
+#ifdef ENABLE_MONITOR
+						if (config->monitor_enabled) {
+							if ((current_server_load > config->max_server_load) && (load_monitor_timer == 0)) {
+								monitor_high_server_load(current_server_load);
+								load_monitor_timer = 60;
+							}
+						}
+#endif
+					} else {
+						current_server_load = 0;
+					}
+				} else {
+					current_server_load = 0;
+				}
+
+				fclose(load_fp);
+			} else {
+				current_server_load = 0;
+			}
+
+#ifdef ENABLE_MONITOR
+			if (load_monitor_timer > 0) {
+				load_monitor_timer--;
+			}
+#endif
+		}
+#endif
+
 		switch (received_signal) {
 			case rs_NONE:
 				break;
@@ -1365,15 +1414,27 @@ int accept_connection(t_binding *binding, t_config *config) {
 		return -1;
 	}
 
-	kick_client = true;
-
 	session->request_limit = (ip_allowed(&(session->ip_address), session->config->request_limit_mask) != deny);
+
+#ifdef ENABLE_LOADCHECK
+	if ((session->config->max_server_load > 0) && session->request_limit) {
+		if (current_server_load > session->config->max_server_load) {
+			close(session->client_socket);
+			free(session);
+			log_string(config->system_logfile, "Connection dropped due to high server load.");
+			return -1;
+		}
+	}
+#endif
+
 	if (session->request_limit == false) {
 		conns_per_ip = config->total_connections;
 	} else {
 		conns_per_ip = config->connections_per_ip;
 	}
 
+	kick_client = true;
+
 	if ((total_conns = connection_allowed(&(session->ip_address), conns_per_ip, config->total_connections)) >= 0) {
 		if (total_conns < (config->total_connections >> 2)) {
 			one = 1;
@@ -1383,16 +1444,16 @@ int accept_connection(t_binding *binding, t_config *config) {
 				log_string(config->system_logfile, "error setsockopt(TCP_NODELAY)");
 				return -1;
 			}
+		}
 
-			if (config->socket_send_timeout > 0) {
-				timer.tv_sec  = config->socket_send_timeout;
-				timer.tv_usec = 0;
-				if (setsockopt(session->client_socket, SOL_SOCKET, SO_SNDTIMEO, &timer, sizeof(struct timeval)) == -1) {
-					close(session->client_socket);
-					free(session);
-					log_string(config->system_logfile, "error setsockopt(SO_SNDTIMEO)");
-					return -1;
-				}
+		if (config->socket_send_timeout > 0) {
+			timer.tv_sec  = config->socket_send_timeout;
+			timer.tv_usec = 0;
+			if (setsockopt(session->client_socket, SOL_SOCKET, SO_SNDTIMEO, &timer, sizeof(struct timeval)) == -1) {
+				close(session->client_socket);
+				free(session);
+				log_string(config->system_logfile, "error setsockopt(SO_SNDTIMEO)");
+				return -1;
 			}
 		}
 
@@ -1787,16 +1848,16 @@ int run_server(t_settings *settings) {
 	/* Start task_runner
 	 */
 	if (pthread_attr_init(&task_runner_attr) != 0) {
-		fprintf(stderr, "Task-runner pthread init error");
+		log_string(config->system_logfile, "Task-runner pthread init error");
 		return -1;
 	} else if (pthread_attr_setdetachstate(&task_runner_attr, PTHREAD_CREATE_DETACHED) != 0) {
-		fprintf(stderr, "Task-runner pthread set detach state error");
+		log_string(config->system_logfile, "Task-runner pthread set detach state error");
 		return -1;
 	} else if (pthread_attr_setstacksize(&task_runner_attr, PTHREAD_STACK_SIZE) != 0) {
-		fprintf(stderr, "Task-runner pthread set stack size error");
+		log_string(config->system_logfile, "Task-runner pthread set stack size error");
 		return -1;
 	} else if (pthread_create(&task_runner_thread, &task_runner_attr, (void*)task_runner, (void*)config) != 0) {
-		fprintf(stderr, "Task-runner pthread create error");
+		log_string(config->system_logfile, "Task-runner pthread create error");
 		return -1;
 	}
 	pthread_attr_destroy(&task_runner_attr);
