@@ -26,9 +26,8 @@
 
 #define BUFFER_SIZE        2 * KILOBYTE
 #define TIMESTAMP_SIZE    40
-#define IP_ADDRESS_SIZE   MAX_IP_STR_LEN + 1
-
-#define LOGFILE_OPEN_TIME   30
+#define IP_ADDRESS_SIZE MAX_IP_STR_LEN + 1
+#define LOGFILE_OPEN_TIME 30
 
 #ifdef CYGWIN
 #define EOL "\r\n"
@@ -140,7 +139,7 @@ void log_system(t_session *session, char *mesg, ...) {
 	strcat(str, "|");
 	print_timestamp(str + strlen(str));
 	fprintf(fp, "%s", str);
-	fprintf(fp, mesg, args);
+	vfprintf(fp, mesg, args);
 	fprintf(fp, EOL);
 	fclose(fp);
 
@@ -149,8 +148,9 @@ void log_system(t_session *session, char *mesg, ...) {
 
 /* Log an error for a specific file
  */
-void log_file_error(t_session *session, char *file, char *mesg) {
+void log_file_error(t_session *session, char *file, char *mesg, ...) {
 	FILE *fp;
+	va_list args;
 	char str[TIMESTAMP_SIZE + IP_ADDRESS_SIZE];
 
 	if ((file == NULL) || (mesg == NULL)) {
@@ -159,11 +159,17 @@ void log_file_error(t_session *session, char *file, char *mesg) {
 		return;
 	}
 
+	va_start(args, mesg);
+
 	ip_to_str(str, &(session->ip_address), IP_ADDRESS_SIZE);
 	strcat(str, "|");
 	print_timestamp(str + strlen(str));
-	fprintf(fp, "%s%s|%s"EOL, str, file, mesg);
+	fprintf(fp, "%s%s|", str, file);
+	vfprintf(fp, mesg, args);
+	fprintf(fp, EOL);
 	fclose(fp);
+
+	va_end(args);
 }
 
 /* Log an error
@@ -383,7 +389,7 @@ void log_unban(char *logfile, t_ip_addr *ip_address, unsigned long connect_attem
 	ip_to_str(str, ip_address, IP_ADDRESS_SIZE);
 	strcat(str, "|");
 	print_timestamp(str + strlen(str));
-	fprintf(fp, "%sUnbanned (%ld connect attempts during ban)\n", str, connect_attempts);
+	fprintf(fp, "%sUnbanned (%ld connect attempts during ban)"EOL, str, connect_attempts);
 	fclose(fp);
 }
 
