@@ -20,7 +20,7 @@ void init_log_module(void);
 void log_pid(t_config *config, pid_t pid);
 void log_string(char *logfile, char *mesg, ...);
 void log_system(t_session *session, char *mesg, ...);
-void log_file_error(t_session *session, char *file, char *mesg);
+void log_file_error(t_session *session, char *file, char *mesg, ...);
 void log_error(t_session *session, char *mesg);
 void log_request(t_session *session);
 void log_garbage(t_session *session);
