@@ -30,11 +30,12 @@
 #include "libfs.h"
 #include "polarssl/md5.h"
 
-char   *rproxy_header;
-size_t rproxy_header_len;
-char   *rproxy_id_key = "X-Hiawatha-RProxy-ID:";
-char   rproxy_id[33];
-int    rproxy_id_len = 10;
+#define RPROXY_ID_LEN 10 /* Must be smaller than 32 */
+
+static char   *rproxy_header;
+static size_t rproxy_header_len;
+static char   *rproxy_id_key = "X-Hiawatha-RProxy-ID:";
+static char   rproxy_id[33];
 
 extern char *hs_forwarded;
 
@@ -54,9 +55,9 @@ int init_rproxy_module(void) {
 
 	md5((unsigned char*)str, strlen(str), digest);
 	md5_bin2hex(digest, rproxy_id);
-	rproxy_id[rproxy_id_len] = '\0';
+	rproxy_id[RPROXY_ID_LEN] = '\0';
 
-	if ((rproxy_header = (char*)malloc(strlen(format) - 4 + strlen(rproxy_id_key) + rproxy_id_len + 1)) == NULL) {
+	if ((rproxy_header = (char*)malloc(strlen(format) - 4 + strlen(rproxy_id_key) + RPROXY_ID_LEN + 1)) == NULL) {
 		return -1;
 	}
 	sprintf(rproxy_header, format, rproxy_id_key, rproxy_id);
@@ -174,12 +175,11 @@ bool rproxy_loop_detected(t_headerfield *headerfields) {
 /* Init reverse proxy options record
  */
 void init_rproxy_options(t_rproxy_options *options, int socket, t_ip_addr *client_ip, char *method,
-                         char *uri, char *vars, t_headerfield *headerfields, char *body, int body_length) {
+                         char *uri, t_headerfield *headerfields, char *body, int body_length) {
 	options->client_socket = socket;
 	options->client_ip = client_ip;
 	options->method = method;
 	options->uri = uri;
-	options->vars = vars;
 	options->headerfields = headerfields;
 	options->body = body;
 	options->body_length = body_length;
@@ -199,18 +199,18 @@ int connect_to_webserver(t_rproxy *rproxy) {
 	}
 
 	if (rproxy->ip_addr.family == AF_INET) {
-	/* IPv4
-	 */
-	if ((sock = socket(AF_INET, SOCK_STREAM, 0)) > 0) {
-		memset(&saddr4, 0, sizeof(struct sockaddr_in));
-		saddr4.sin_family = AF_INET;
-		saddr4.sin_port = htons(rproxy->port);
-		memcpy(&saddr4.sin_addr.s_addr, &(rproxy->ip_addr.value), rproxy->ip_addr.size);
-		if (connect(sock, (struct sockaddr*)&saddr4, sizeof(struct sockaddr_in)) != 0) {
-			close(sock);
-			sock = -1;
+		/* IPv4
+		 */
+		if ((sock = socket(AF_INET, SOCK_STREAM, 0)) > 0) {
+			memset(&saddr4, 0, sizeof(struct sockaddr_in));
+			saddr4.sin_family = AF_INET;
+			saddr4.sin_port = htons(rproxy->port);
+			memcpy(&saddr4.sin_addr.s_addr, &(rproxy->ip_addr.value), rproxy->ip_addr.size);
+			if (connect(sock, (struct sockaddr*)&saddr4, sizeof(struct sockaddr_in)) != 0) {
+				close(sock);
+				sock = -1;
+			}
 		}
-	}
 #ifdef ENABLE_IPV6
 	} else if (rproxy->ip_addr.family == AF_INET6) {
 		/* IPv6
@@ -277,16 +277,6 @@ int send_request_to_webserver(t_rproxy_webserver *webserver, t_rproxy_options *o
 		return -1;
 	}
 
-	/* URL parameters
-	 */
-	if (options->vars != NULL) {
-		if (send_to_webserver(webserver, "?", 1) == -1) {
-			return -1;
-		} else if (send_to_webserver(webserver, options->vars, strlen(options->vars)) == -1) {
-			return -1;
-		}
-	}
-
 	/* Send HTTP headers
 	 */
 	if (send_to_webserver(webserver, "Host: ", 6) == -1) {
