@@ -33,10 +33,10 @@
 #endif
 
 #define MAX_CHUNK_SIZE 2048
-#define MAX_TO_BUFFER 400
-#define NONCE_DIGITS 10
-#define SEND_TIMEOUT 5
-#define TIMESTR_SIZE 64
+#define MAX_TO_BUFFER   400
+#define NONCE_DIGITS     10
+#define SEND_TIMEOUT      5
+#define TIMESTR_SIZE     64
 
 char *hs_http10  = "HTTP/1.0 ";                  /*  9 */
 char *hs_http11  = "HTTP/1.1 ";                  /*  9 */
@@ -53,7 +53,7 @@ char *hs_range   = "Accept-Ranges: bytes\r\n";   /* 22 */
 char *hs_gzip    = "Content-Encoding: gzip\r\n"; /* 24 */
 char *hs_eol     = "\r\n";                       /*  2 */
 
-char *unknown_code = "Unknown Error";
+static char *unknown_code = "Unknown Error";
 
 /* Send a char buffer to the client. Traffic throttling is handled here.
  */
