@@ -40,9 +40,9 @@ enum t_section { syntax_error = -1, none, binding, virtual_host, directory, fcgi
 #endif
 	};
 
-bool including = false;
-t_keyvalue *variables = NULL;
-char *index_xslt = CONFIG_DIR"/index.xslt";
+static bool including = false;
+static t_keyvalue *variables = NULL;
+static char *index_xslt = CONFIG_DIR"/index.xslt";
 
 static t_host *new_host(void) {
 	t_host *host;
@@ -310,6 +310,10 @@ t_config *default_config(void) {
 	config->platform           = windows;
 #endif
 
+#ifdef ENABLE_LOADCHECK
+	config->max_server_load    = 0;
+#endif
+
 #ifdef ENABLE_CACHE
 	config->cache_size         = 10 * MEGABYTE;
 	config->cache_max_filesize = 256 * KILOBYTE;
@@ -825,6 +829,12 @@ static bool system_setting(char *key, char *value, t_config *config) {
 		if ((config->logfile_mask = parse_accesslist(value, false, config->logfile_mask)) != NULL) {
 			return true;
 		}
+#ifdef ENABLE_LOADCHECK
+	} else if (strcmp(key, "maxserverload") == 0) {
+		if ((config->max_server_load = atof(value)) > 0) {
+			return true;
+		}
+#endif
 	} else if (strcmp(key, "maxurllength") == 0) {
 		if (strcmp(value, "none") == 0) {
 			config->max_url_length = 0;
