@@ -311,6 +311,10 @@ typedef struct type_config {
 	char          *upload_directory;
 	size_t        upload_directory_len;
 
+#ifdef ENABLE_LOADCHECK
+	double        max_server_load;
+#endif
+
 #ifdef ENABLE_CACHE
 	off_t         cache_size;
 	off_t         cache_max_filesize;
