@@ -353,12 +353,14 @@ int load_user_config(t_session *session) {
 				memcpy(conffile, session->file_on_disk, length);
 				memcpy(conffile + length, ".hiawatha\0", 10);
 				result = read_user_configfile(conffile, session->host, &(session->tempdata));
-				free(conffile);
 
-				if (result == -1) {
-					log_file_error(session, conffile, "error in configuration file");
+				if (result != 0) {
+					log_file_error(session, conffile, "error in configuration file on line %d", result);
+					free(conffile);
 					return -1;
 				}
+
+				free(conffile);
 			}
 		}
 
