@@ -48,7 +48,7 @@ typedef struct {
 
 typedef enum { cgi, cmd } t_exec_type;
 
-char *CURRENT_DIRECTORY = ".";
+static char *CURRENT_DIRECTORY = ".";
 
 int process_ssi_file(t_config *config, char *file);
 
