@@ -62,10 +62,7 @@
 
 #define NEW_FILE -1
 
-char *hs_chunked = "Transfer-Encoding: chunked\r\n";
-char *hs_post    = ", POST";
-char *hs_trace   = ", TRACE";
-char *hs_alter   = ", PUT, DELETE";
+static char *hs_chunked = "Transfer-Encoding: chunked\r\n";
 
 extern char *fb_filesystem;
 extern char *fb_symlink;
@@ -1367,9 +1364,8 @@ int proxy_request(t_session *session, t_rproxy *rproxy) {
 
 	/* Intialize data structure
 	 */
-	init_rproxy_options(&options, session->client_socket, &(session->ip_address),
-	                    session->method, session->request_uri, session->vars,
-	                    session->headerfields, session->body, session->content_length);
+	init_rproxy_options(&options, session->client_socket, &(session->ip_address), session->method,
+	                    session->request_uri, session->headerfields, session->body, session->content_length);
 
 	session->keep_alive = false;
 
