@@ -29,14 +29,14 @@
 #include "command.h"
 #endif
 
-#define VALUE_SIZE 16
-#define LINE_SIZE 1024
 #define XSLT_INDEX "/index.xslt\0"
-#define XSLT_INDEX_LEN 12
-#define MAX_PARAMETERS 200 /* must be even */
-#define MAX_NAME_LEN 100
-#define MAX_HEADER_LEN 100
-#define XML_CHUNK_LEN 2048
+#define XSLT_INDEX_LEN   12
+#define VALUE_SIZE       16
+#define LINE_SIZE      1024
+#define MAX_PARAMETERS  200 /* must be even */
+#define MAX_NAME_LEN    100
+#define MAX_HEADER_LEN  100
+#define XML_CHUNK_LEN  2048
 
 extern char *hs_conlen;
 extern char *fb_filesystem;
@@ -180,7 +180,7 @@ static const char **get_transform_parameters(t_session *session) {
 	snprintf(value, 9, "%d", session->binding->port);
 	add_parameter(params, "SERVER_PORT", value, &i);
 	add_parameter(params, "SERVER_NAME", *(session->host->hostname.item), &i);
-	add_parameter(params, "SERVER_SOFTWARE", "Hiawatha v"VERSION, &i);
+	add_parameter(params, "SERVER_SOFTWARE", session->config->server_string, &i);
 #ifdef ENABLE_SSL
 	if (session->binding->use_ssl) {
 		add_parameter(params, "HTTP_SCHEME", "https", &i);
@@ -793,7 +793,7 @@ int show_index(t_session *session) {
 	if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "total_size", fsize_str) == -1) {
 		free(text_xml);
 		return -1;
-	} else if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "software", "Hiawatha v"VERSION) == -1) {
+	} else if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "software", session->config->server_string) == -1) {
 		free(text_xml);
 		return -1;
 	} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "</index>") == -1) {
